@@ -5,17 +5,20 @@ class Translator:
     def __init__(self, adapter: Adapter):
         self._adapter = adapter
 
-    def translate(self, text, target_lang, *, source_lang=None, split_sentences=None, preserve_formatting=None, formality=None):
+    def translate(self, text, target_lang, *,
+                  source_lang=None, split_sentences=None, preserve_formatting=None, formality=None):
         payload = {
             'text': text,
             'target_lang': str(target_lang)
         }
         if source_lang:
-            payload['source_lang'] = source_lang
+            payload['source_lang'] = str(source_lang)
         if split_sentences:
-            payload['split_sentences'] = preserve_formatting
+            payload['split_sentences'] = split_sentences
+        if preserve_formatting:
+            payload['preserve_formatting'] = preserve_formatting
         if formality:
-            payload['formality'] = formality
+            payload['formality'] = str(formality)
         return self._adapter.get_translated_text(payload)
 
     def usage(self):
@@ -23,4 +26,3 @@ class Translator:
 
     def supported_languages(self):
         return self._adapter.get_supported_languages()
-
